@@ -2,8 +2,8 @@
 # housekeeping
 ########################################################################
 
-package Parallel::Queue v3.4.0;
-use v5.12;
+package Parallel::Queue;
+use v5.10;
 
 use strict;
 
@@ -15,6 +15,8 @@ use Symbol          qw( qualify_to_ref              );
 # package variables
 ########################################################################
 
+our $VERSION    = v3.1;
+
 # defaults.
 
 my  $fork       = '';
@@ -314,10 +316,8 @@ sub import
             looks_like_number $value 
             or $subname = $value;
         }
-        else
-        {
-            warn "Unknown argument: '$arg' ignored";
-        }
+
+        warn "Unknown argument: '$arg' ignored";
     }
 
     if( $fork && $^P && ! $DB::fork_TTY )
@@ -351,8 +351,7 @@ __END__
 
 =head1 NAME
 
-Parallel::Queue - fork subref's N-way parallel as static list or as 
-generated by an object.
+Parallel::Queue - fork list of subref's N-way parallel
 
 =head1 SYNOPSIS
 
@@ -380,7 +379,7 @@ generated by an object.
     # __PACKAGE__ if the package sets itself up to 
     # handle the paralell jobs.
 
-    my $iter   = Foo->new( @job_parmz );
+    my $iter    = Foo->new( @job_parmz );
     runqueue 4 => $iter;
 
     $pkg->configure( @job_parmz );
@@ -447,13 +446,15 @@ subroune into the caller.
 
 =over 4
 
-=item finish (default finish=0)
+=item finish
+=item finish=0
 
 This causes the queue to finsih even if there are
 non-zero exits on the way. Exits will be logged 
 but will not stop the queue. 
 
-=item export=my_name (default export=runqueue)
+=item export=my_name
+=item export=
 
 By default Parallel::Queue exports "runqueue", this can
 be changed with the "export" arguments. In this case
@@ -506,17 +507,13 @@ which don't look like numbers.
 
 =head1 SEE ALSO
 
-=over 4
-
 =item Debugging forks.
 
 <http://perlmonks.org/index.pl?node_id=128283>
 
-=back
-
 =head1 COPYRIGHT
 
-This code is released under the same terms as Perl-5.20
+This code is released under the same terms as Perl-5.8
 or any later version of Perl.
 
 =head1 AUTHOR
